LEAF_PREFIX = b'\x00'
NODE_PREFIX = b'\x01'
ROOT_CACHE_PATH = "rootfile"

PERMISSION_SYS_ADMIN = 255
PERMISSION_ADMIN = 254
PERMISSION_NONE = 0
PERMISSION_R = 1
PERMISSION_RW = 2

SET_KEY_PREFIX=b'\x00'
SORTED_KEY_PREFIX=b'\x01'

PLAIN_VALUE_PREFIX=b'\x00'
REFERENCE_VALUE_PREFIX=b'\x01'

OLDEST_FIRST=False
NEWEST_FIRST=True

