# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import schema_pb2 as schema__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='lc.proto',
  package='lc.schema',
  syntax='proto3',
  serialized_options=b'Z4github.com/vchain-us/ledger-compliance/server/schema',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x08lc.proto\x12\tlc.schema\x1a\x0cschema.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"8\n\x0cTamperReport\x12\r\n\x05index\x18\x01 \x01(\x04\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0c\n\x04root\x18\x03 \x01(\x0c\"f\n\rReportOptions\x12(\n\x07payload\x18\x01 \x01(\x0b\x32\x17.lc.schema.TamperReport\x12+\n\tsignature\x18\x02 \x01(\x0b\x32\x18.immudb.schema.Signature\"6\n\tDataValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x0c\"f\n\x04\x44\x61ta\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05msgID\x18\x02 \x01(\x03\x12\x0e\n\x06\x64\x62Name\x18\x03 \x01(\t\x12\x11\n\ttableName\x18\x04 \x01(\t\x12\x11\n\toperation\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\"\x97\x01\n\x08Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\r\n\x05msgID\x18\x03 \x01(\x03\x12\x31\n\x0cVerifiableTx\x18\x04 \x01(\x0b\x32\x1b.immudb.schema.VerifiableTx\x12,\n\x05state\x18\x05 \x01(\x0b\x32\x1d.immudb.schema.ImmutableState\"p\n\x11VerifiableItemExt\x12,\n\x04item\x18\x01 \x01(\x0b\x32\x1e.immudb.schema.VerifiableEntry\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\\\n\x07ItemExt\x12\"\n\x04item\x18\x01 \x01(\x0b\x32\x14.immudb.schema.Entry\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"0\n\x0bItemExtList\x12!\n\x05items\x18\x01 \x03(\x0b\x32\x12.lc.schema.ItemExt\"^\n\x08ZItemExt\x12#\n\x04item\x18\x01 \x01(\x0b\x32\x15.immudb.schema.ZEntry\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"2\n\x0cZItemExtList\x12\"\n\x05items\x18\x01 \x03(\x0b\x32\x13.lc.schema.ZItemExt2\x82\n\n\tLcService\x12=\n\x03Set\x12\x19.immudb.schema.SetRequest\x1a\x19.immudb.schema.TxMetadata\"\x00\x12\x38\n\x03Get\x12\x19.immudb.schema.KeyRequest\x1a\x14.immudb.schema.Entry\"\x00\x12S\n\rVerifiableSet\x12#.immudb.schema.VerifiableSetRequest\x1a\x1b.immudb.schema.VerifiableTx\"\x00\x12V\n\rVerifiableGet\x12#.immudb.schema.VerifiableGetRequest\x1a\x1e.immudb.schema.VerifiableEntry\"\x00\x12\x41\n\x06GetAll\x12\x1d.immudb.schema.KeyListRequest\x1a\x16.immudb.schema.Entries\"\x00\x12\x45\n\x07\x45xecAll\x12\x1d.immudb.schema.ExecAllRequest\x1a\x19.immudb.schema.TxMetadata\"\x00\x12<\n\x04Scan\x12\x1a.immudb.schema.ScanRequest\x1a\x16.immudb.schema.Entries\"\x00\x12\x42\n\x07History\x12\x1d.immudb.schema.HistoryRequest\x1a\x16.immudb.schema.Entries\"\x00\x12?\n\x04ZAdd\x12\x1a.immudb.schema.ZAddRequest\x1a\x19.immudb.schema.TxMetadata\"\x00\x12U\n\x0eVerifiableZAdd\x12$.immudb.schema.VerifiableZAddRequest\x1a\x1b.immudb.schema.VerifiableTx\"\x00\x12?\n\x05ZScan\x12\x1b.immudb.schema.ZScanRequest\x1a\x17.immudb.schema.ZEntries\"\x00\x12G\n\x0c\x43urrentState\x12\x16.google.protobuf.Empty\x1a\x1d.immudb.schema.ImmutableState\"\x00\x12\x41\n\x06Health\x12\x16.google.protobuf.Empty\x1a\x1d.immudb.schema.HealthResponse\"\x00\x12\x42\n\x0cReportTamper\x12\x18.lc.schema.ReportOptions\x1a\x16.google.protobuf.Empty\"\x00\x12\x36\n\x08SendData\x12\x0f.lc.schema.Data\x1a\x13.lc.schema.Response\"\x00(\x01\x30\x01\x12W\n\x10VerifiableGetExt\x12#.immudb.schema.VerifiableGetRequest\x1a\x1c.lc.schema.VerifiableItemExt\"\x00\x12\x42\n\x08ZScanExt\x12\x1b.immudb.schema.ZScanRequest\x1a\x17.lc.schema.ZItemExtList\"\x00\x12\x45\n\nHistoryExt\x12\x1d.immudb.schema.HistoryRequest\x1a\x16.lc.schema.ItemExtList\"\x00\x42\x36Z4github.com/vchain-us/ledger-compliance/server/schemab\x06proto3'
  ,
  dependencies=[schema__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_TAMPERREPORT = _descriptor.Descriptor(
  name='TamperReport',
  full_name='lc.schema.TamperReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='lc.schema.TamperReport.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='lc.schema.TamperReport.key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root', full_name='lc.schema.TamperReport.root', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=155,
)


_REPORTOPTIONS = _descriptor.Descriptor(
  name='ReportOptions',
  full_name='lc.schema.ReportOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='lc.schema.ReportOptions.payload', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='lc.schema.ReportOptions.signature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=259,
)


_DATAVALUE = _descriptor.Descriptor(
  name='DataValue',
  full_name='lc.schema.DataValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='lc.schema.DataValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='lc.schema.DataValue.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='lc.schema.DataValue.value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=315,
)


_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='lc.schema.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='lc.schema.Data.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msgID', full_name='lc.schema.Data.msgID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dbName', full_name='lc.schema.Data.dbName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tableName', full_name='lc.schema.Data.tableName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='lc.schema.Data.operation', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='lc.schema.Data.data', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=419,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='lc.schema.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='lc.schema.Response.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='lc.schema.Response.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msgID', full_name='lc.schema.Response.msgID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='VerifiableTx', full_name='lc.schema.Response.VerifiableTx', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='lc.schema.Response.state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=573,
)


_VERIFIABLEITEMEXT = _descriptor.Descriptor(
  name='VerifiableItemExt',
  full_name='lc.schema.VerifiableItemExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='lc.schema.VerifiableItemExt.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='lc.schema.VerifiableItemExt.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=687,
)


_ITEMEXT = _descriptor.Descriptor(
  name='ItemExt',
  full_name='lc.schema.ItemExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='lc.schema.ItemExt.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='lc.schema.ItemExt.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=781,
)


_ITEMEXTLIST = _descriptor.Descriptor(
  name='ItemExtList',
  full_name='lc.schema.ItemExtList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='lc.schema.ItemExtList.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=831,
)


_ZITEMEXT = _descriptor.Descriptor(
  name='ZItemExt',
  full_name='lc.schema.ZItemExt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='lc.schema.ZItemExt.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='lc.schema.ZItemExt.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=927,
)


_ZITEMEXTLIST = _descriptor.Descriptor(
  name='ZItemExtList',
  full_name='lc.schema.ZItemExtList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='lc.schema.ZItemExtList.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=929,
  serialized_end=979,
)

_REPORTOPTIONS.fields_by_name['payload'].message_type = _TAMPERREPORT
_REPORTOPTIONS.fields_by_name['signature'].message_type = schema__pb2._SIGNATURE
_RESPONSE.fields_by_name['VerifiableTx'].message_type = schema__pb2._VERIFIABLETX
_RESPONSE.fields_by_name['state'].message_type = schema__pb2._IMMUTABLESTATE
_VERIFIABLEITEMEXT.fields_by_name['item'].message_type = schema__pb2._VERIFIABLEENTRY
_VERIFIABLEITEMEXT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ITEMEXT.fields_by_name['item'].message_type = schema__pb2._ENTRY
_ITEMEXT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ITEMEXTLIST.fields_by_name['items'].message_type = _ITEMEXT
_ZITEMEXT.fields_by_name['item'].message_type = schema__pb2._ZENTRY
_ZITEMEXT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ZITEMEXTLIST.fields_by_name['items'].message_type = _ZITEMEXT
DESCRIPTOR.message_types_by_name['TamperReport'] = _TAMPERREPORT
DESCRIPTOR.message_types_by_name['ReportOptions'] = _REPORTOPTIONS
DESCRIPTOR.message_types_by_name['DataValue'] = _DATAVALUE
DESCRIPTOR.message_types_by_name['Data'] = _DATA
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['VerifiableItemExt'] = _VERIFIABLEITEMEXT
DESCRIPTOR.message_types_by_name['ItemExt'] = _ITEMEXT
DESCRIPTOR.message_types_by_name['ItemExtList'] = _ITEMEXTLIST
DESCRIPTOR.message_types_by_name['ZItemExt'] = _ZITEMEXT
DESCRIPTOR.message_types_by_name['ZItemExtList'] = _ZITEMEXTLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TamperReport = _reflection.GeneratedProtocolMessageType('TamperReport', (_message.Message,), {
  'DESCRIPTOR' : _TAMPERREPORT,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.TamperReport)
  })
_sym_db.RegisterMessage(TamperReport)

ReportOptions = _reflection.GeneratedProtocolMessageType('ReportOptions', (_message.Message,), {
  'DESCRIPTOR' : _REPORTOPTIONS,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.ReportOptions)
  })
_sym_db.RegisterMessage(ReportOptions)

DataValue = _reflection.GeneratedProtocolMessageType('DataValue', (_message.Message,), {
  'DESCRIPTOR' : _DATAVALUE,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.DataValue)
  })
_sym_db.RegisterMessage(DataValue)

Data = _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), {
  'DESCRIPTOR' : _DATA,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.Data)
  })
_sym_db.RegisterMessage(Data)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.Response)
  })
_sym_db.RegisterMessage(Response)

VerifiableItemExt = _reflection.GeneratedProtocolMessageType('VerifiableItemExt', (_message.Message,), {
  'DESCRIPTOR' : _VERIFIABLEITEMEXT,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.VerifiableItemExt)
  })
_sym_db.RegisterMessage(VerifiableItemExt)

ItemExt = _reflection.GeneratedProtocolMessageType('ItemExt', (_message.Message,), {
  'DESCRIPTOR' : _ITEMEXT,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.ItemExt)
  })
_sym_db.RegisterMessage(ItemExt)

ItemExtList = _reflection.GeneratedProtocolMessageType('ItemExtList', (_message.Message,), {
  'DESCRIPTOR' : _ITEMEXTLIST,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.ItemExtList)
  })
_sym_db.RegisterMessage(ItemExtList)

ZItemExt = _reflection.GeneratedProtocolMessageType('ZItemExt', (_message.Message,), {
  'DESCRIPTOR' : _ZITEMEXT,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.ZItemExt)
  })
_sym_db.RegisterMessage(ZItemExt)

ZItemExtList = _reflection.GeneratedProtocolMessageType('ZItemExtList', (_message.Message,), {
  'DESCRIPTOR' : _ZITEMEXTLIST,
  '__module__' : 'lc_pb2'
  # @@protoc_insertion_point(class_scope:lc.schema.ZItemExtList)
  })
_sym_db.RegisterMessage(ZItemExtList)


DESCRIPTOR._options = None

_LCSERVICE = _descriptor.ServiceDescriptor(
  name='LcService',
  full_name='lc.schema.LcService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=982,
  serialized_end=2264,
  methods=[
  _descriptor.MethodDescriptor(
    name='Set',
    full_name='lc.schema.LcService.Set',
    index=0,
    containing_service=None,
    input_type=schema__pb2._SETREQUEST,
    output_type=schema__pb2._TXMETADATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='lc.schema.LcService.Get',
    index=1,
    containing_service=None,
    input_type=schema__pb2._KEYREQUEST,
    output_type=schema__pb2._ENTRY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifiableSet',
    full_name='lc.schema.LcService.VerifiableSet',
    index=2,
    containing_service=None,
    input_type=schema__pb2._VERIFIABLESETREQUEST,
    output_type=schema__pb2._VERIFIABLETX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifiableGet',
    full_name='lc.schema.LcService.VerifiableGet',
    index=3,
    containing_service=None,
    input_type=schema__pb2._VERIFIABLEGETREQUEST,
    output_type=schema__pb2._VERIFIABLEENTRY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAll',
    full_name='lc.schema.LcService.GetAll',
    index=4,
    containing_service=None,
    input_type=schema__pb2._KEYLISTREQUEST,
    output_type=schema__pb2._ENTRIES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecAll',
    full_name='lc.schema.LcService.ExecAll',
    index=5,
    containing_service=None,
    input_type=schema__pb2._EXECALLREQUEST,
    output_type=schema__pb2._TXMETADATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Scan',
    full_name='lc.schema.LcService.Scan',
    index=6,
    containing_service=None,
    input_type=schema__pb2._SCANREQUEST,
    output_type=schema__pb2._ENTRIES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='History',
    full_name='lc.schema.LcService.History',
    index=7,
    containing_service=None,
    input_type=schema__pb2._HISTORYREQUEST,
    output_type=schema__pb2._ENTRIES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ZAdd',
    full_name='lc.schema.LcService.ZAdd',
    index=8,
    containing_service=None,
    input_type=schema__pb2._ZADDREQUEST,
    output_type=schema__pb2._TXMETADATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifiableZAdd',
    full_name='lc.schema.LcService.VerifiableZAdd',
    index=9,
    containing_service=None,
    input_type=schema__pb2._VERIFIABLEZADDREQUEST,
    output_type=schema__pb2._VERIFIABLETX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ZScan',
    full_name='lc.schema.LcService.ZScan',
    index=10,
    containing_service=None,
    input_type=schema__pb2._ZSCANREQUEST,
    output_type=schema__pb2._ZENTRIES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CurrentState',
    full_name='lc.schema.LcService.CurrentState',
    index=11,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=schema__pb2._IMMUTABLESTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Health',
    full_name='lc.schema.LcService.Health',
    index=12,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=schema__pb2._HEALTHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReportTamper',
    full_name='lc.schema.LcService.ReportTamper',
    index=13,
    containing_service=None,
    input_type=_REPORTOPTIONS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendData',
    full_name='lc.schema.LcService.SendData',
    index=14,
    containing_service=None,
    input_type=_DATA,
    output_type=_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifiableGetExt',
    full_name='lc.schema.LcService.VerifiableGetExt',
    index=15,
    containing_service=None,
    input_type=schema__pb2._VERIFIABLEGETREQUEST,
    output_type=_VERIFIABLEITEMEXT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ZScanExt',
    full_name='lc.schema.LcService.ZScanExt',
    index=16,
    containing_service=None,
    input_type=schema__pb2._ZSCANREQUEST,
    output_type=_ZITEMEXTLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HistoryExt',
    full_name='lc.schema.LcService.HistoryExt',
    index=17,
    containing_service=None,
    input_type=schema__pb2._HISTORYREQUEST,
    output_type=_ITEMEXTLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LCSERVICE)

DESCRIPTOR.services_by_name['LcService'] = _LCSERVICE

# @@protoc_insertion_point(module_scope)
